@@ -14,7 +14,7 @@
 
 #include "literecipedb.h"
 
-#include <ntqbuffer.h>
+#include <tqbuffer.h>
 
 #include <kdebug.h>
 #include <tdeconfig.h>
