@@ -30,9 +30,9 @@
 #include <kfilterdev.h>
 #include <tdemessagebox.h>
 
-#include <ntqfile.h>
-#include <ntqstringlist.h>
-#include <ntqtextstream.h>
+#include <tqfile.h>
+#include <tqstringlist.h>
+#include <tqtextstream.h>
 
 #include <map>
 
