@@ -11,8 +11,8 @@
 #ifndef KREBORDER_H
 #define KREBORDER_H
 
-#include <ntqcolor.h>
-#include <ntqstring.h>
+#include <tqcolor.h>
+#include <tqstring.h>
 
 //typedef enum KreBorderStyle { None = 0, Dotted, Dashed, Solid, Double, Groove, Ridge, Inset, Outset };
 
