@@ -10,14 +10,14 @@
 
 #include "borderdialog.h"
 
-#include <ntqpushbutton.h>
-#include <ntqgroupbox.h>
-#include <ntqvbox.h>
-#include <ntqlabel.h>
-#include <ntqspinbox.h>
-#include <ntqlayout.h>
-#include <ntqtooltip.h>
-#include <ntqwhatsthis.h>
+#include <tqpushbutton.h>
+#include <tqgroupbox.h>
+#include <tqvbox.h>
+#include <tqlabel.h>
+#include <tqspinbox.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
 
 #include <kdebug.h>
 #include <tdehtml_part.h>
