@@ -10,15 +10,15 @@
 
 #include "conversiondialog.h"
 
-#include <ntqvariant.h>
-#include <ntqpushbutton.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
 #include <kcombobox.h>
-#include <ntqlabel.h>
+#include <tqlabel.h>
 #include <klineedit.h>
-#include <ntqlayout.h>
-#include <ntqtooltip.h>
-#include <ntqwhatsthis.h>
-#include <ntqvbox.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
+#include <tqvbox.h>
 
 #include <kcombobox.h>
 #include <klineedit.h>
