@@ -17,17 +17,17 @@
 #include "config.h"
 #endif
 
-#include <ntqpushbutton.h>
-#include <ntqbuttongroup.h>
-#include <ntqradiobutton.h>
-#include <ntqwidgetstack.h>
-#include <ntqwidget.h>
-#include <ntqlineedit.h>
-#include <ntqlabel.h>
-#include <ntqlayout.h>
-#include <ntqtooltip.h>
-#include <ntqwhatsthis.h>
-#include <ntqhbox.h>
+#include <tqpushbutton.h>
+#include <tqbuttongroup.h>
+#include <tqradiobutton.h>
+#include <tqwidgetstack.h>
+#include <tqwidget.h>
+#include <tqlineedit.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
+#include <tqhbox.h>
 
 #include <tdeconfig.h>
 #include <kdebug.h>
