@@ -12,20 +12,20 @@
 
 #include <tdelocale.h>
 
-#include <ntqvariant.h>
-#include <ntqpushbutton.h>
-#include <ntqlabel.h>
-#include <ntqcombobox.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqlabel.h>
+#include <tqcombobox.h>
 #include <knuminput.h>
-#include <ntqheader.h>
+#include <tqheader.h>
 #include <tdelistview.h>
-#include <ntqtextedit.h>
-#include <ntqlineedit.h>
-#include <ntqlayout.h>
-#include <ntqtooltip.h>
-#include <ntqwhatsthis.h>
-#include <ntqpainter.h>
-#include <ntqvbox.h>
+#include <tqtextedit.h>
+#include <tqlineedit.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
+#include <tqpainter.h>
+#include <tqvbox.h>
 
 #include <tdepopupmenu.h>
 #include <tdelocale.h>
