@@ -14,19 +14,19 @@
 
 #include "recipeinputdialog.h"
 
-#include <ntqstring.h>
-#include <ntqlayout.h>
-#include <ntqhbox.h>
-#include <ntqvbox.h>
-#include <ntqimage.h>
-#include <ntqmessagebox.h>
-#include <ntqtooltip.h>
-#include <ntqdatetimeedit.h>
-#include <ntqdragobject.h>
-#include <ntqbuttongroup.h>
-#include <ntqradiobutton.h>
-#include <ntqwidgetstack.h>
-#include <ntqpainter.h>
+#include <tqstring.h>
+#include <tqlayout.h>
+#include <tqhbox.h>
+#include <tqvbox.h>
+#include <tqimage.h>
+#include <tqmessagebox.h>
+#include <tqtooltip.h>
+#include <tqdatetimeedit.h>
+#include <tqdragobject.h>
+#include <tqbuttongroup.h>
+#include <tqradiobutton.h>
+#include <tqwidgetstack.h>
+#include <tqpainter.h>
 
 #include <tdeapplication.h>
 #include <tdecompletionbox.h>
