@@ -9,15 +9,15 @@
 
 #include "similarcategoriesdialog.h"
 
-#include <ntqvariant.h>
-#include <ntqpushbutton.h>
-#include <ntqcombobox.h>
-#include <ntqslider.h>
-#include <ntqlabel.h>
-#include <ntqheader.h>
-#include <ntqlayout.h>
-#include <ntqtooltip.h>
-#include <ntqwhatsthis.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqcombobox.h>
+#include <tqslider.h>
+#include <tqlabel.h>
+#include <tqheader.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
 
 #include <tdelistview.h>
 #include <tdelocale.h>
