@@ -10,11 +10,11 @@
 
 #include "cookmlexporter.h"
 
-#include <ntqbuffer.h>
-#include <ntqdom.h>
-#include <ntqimage.h>
-#include <ntqpixmap.h>
-#include <ntqfile.h>
+#include <tqbuffer.h>
+#include <tqdom.h>
+#include <tqimage.h>
+#include <tqpixmap.h>
+#include <tqfile.h>
 
 #include <tdeconfig.h>
 #include <kdebug.h>
