@@ -15,10 +15,10 @@
 
 #include <cstdlib>
 
-#include <ntqlayout.h>
-#include <ntqimage.h>
-#include <ntqpainter.h>
-#include <ntqpalette.h>
+#include <tqlayout.h>
+#include <tqimage.h>
+#include <tqpainter.h>
+#include <tqpalette.h>
 
 #include <tdeapplication.h>
 #include <tdeconfig.h>
