@@ -18,17 +18,17 @@
 #include "config.h"
 #endif
 
-#include <ntqlayout.h>
-#include <ntqlabel.h>
-#include <ntqhbox.h>
-#include <ntqbuttongroup.h>
-#include <ntqcheckbox.h>
-#include <ntqradiobutton.h>
-#include <ntqpushbutton.h>
-#include <ntqtooltip.h>
-#include <ntqwhatsthis.h>
-#include <ntqframe.h>
-#include <ntqcombobox.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqhbox.h>
+#include <tqbuttongroup.h>
+#include <tqcheckbox.h>
+#include <tqradiobutton.h>
+#include <tqpushbutton.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
+#include <tqframe.h>
+#include <tqcombobox.h>
 
 #include <tdeapplication.h>
 #include <tdeconfig.h>
