@@ -16,12 +16,12 @@
 #include <unistd.h>
 #include <pwd.h>
 
-#include <ntqhbox.h>
-#include <ntqvgroupbox.h>
-#include <ntqlayout.h>
-#include <ntqpixmap.h>
-#include <ntqpushbutton.h>
-#include <ntqtooltip.h>
+#include <tqhbox.h>
+#include <tqvgroupbox.h>
+#include <tqlayout.h>
+#include <tqpixmap.h>
+#include <tqpushbutton.h>
+#include <tqtooltip.h>
 
 #include <tdeconfig.h>
 #include <kdebug.h>
