@@ -15,7 +15,7 @@
 #include "datablocks/mixednumber.h"
 #include "widgets/fractioninput.h"
 
-#include <ntqtooltip.h>
+#include <tqtooltip.h>
 
 #include <tdeglobal.h>
 #include <tdelocale.h>
