@@ -14,14 +14,14 @@
 
 #include "ingredientinputwidget.h"
 
-#include <ntqlabel.h>
-#include <ntqwidgetstack.h>
-#include <ntqhbox.h>
-#include <ntqvbox.h>
-#include <ntqgroupbox.h>
-#include <ntqbuttongroup.h>
-#include <ntqradiobutton.h>
-#include <ntqcheckbox.h>
+#include <tqlabel.h>
+#include <tqwidgetstack.h>
+#include <tqhbox.h>
+#include <tqvbox.h>
+#include <tqgroupbox.h>
+#include <tqbuttongroup.h>
+#include <tqradiobutton.h>
+#include <tqcheckbox.h>
 
 #include <kcombobox.h>
 #include <tdelocale.h>
